package cn.com.infosec.mobile.android;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.net.ConnectivityManager;
import android.os.Build;
import android.os.Build.VERSION;
import android.support.annotation.Keep;
import android.support.annotation.NonNull;
import android.text.TextUtils;
import cn.com.infosec.jce.provider.InfosecProvider;
import cn.com.infosec.mobile.android.log.JSONFormatter;
import cn.com.infosec.mobile.android.log.MAuthHandler;
import cn.com.infosec.mobile.android.net.NetworkInterface;
import cn.com.infosec.mobile.android.result.Result;
import cn.com.infosec.mobile.android.util.Util;
import cn.com.infosec.mobile.android.xlog.LogConfiguration;
import cn.com.infosec.mobile.android.xlog.XLog;
import cn.com.infosec.mobile.android.xlog.flattener.ClassicFlattener;
import cn.com.infosec.mobile.android.xlog.interceptor.BlacklistTagsFilterInterceptor;
import cn.com.infosec.mobile.android.xlog.printer.AndroidPrinter;
import cn.com.infosec.mobile.android.xlog.printer.Printer;
import cn.com.infosec.mobile.android.xlog.printer.file.FilePrinter;
import cn.com.infosec.mobile.android.xlog.printer.file.backup.FileSizeBackupStrategy;
import cn.com.infosec.mobile.android.xlog.printer.file.clean.FileLastModifiedCleanStrategy;
import cn.com.infosec.mobile.android.xlog.printer.file.naming.DateFileNameGenerator;
import cn.com.infosec.mobile.android.xlog.printer.file.writer.SimpleWriter;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.security.Security;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.logging.Logger;
import org.json.JSONObject;

@Keep
public class IMSSdk {
   @Keep
   public static int errCode;
   @Keep
   public static String errMessage;
   public static Context mContext;
   public static String APP_NAME;
   private static NetworkStateReceiver networkStateReceiver;
   private static boolean monitoringNetworkState;
   public static NetworkInterface networkInterface;
   public static Logger mLogger;
   public static int timeoutMillSeconds;
   public static final String IMSSDK_LOG_NAME = "IMSSDK_LOG";
   public static final String BACKUP_LOG_FILE_NAME = "IMSSDK_LOG_REMAINING.txt";
   public static String appIDentifier;
   public static String appSecretKey;
   public static boolean isAppIndex;
   public static String appIndex;
   public static String appSep;
   public static boolean enableLogRequestTime;
   public static boolean enableDebugLog;
   private static final String LOG_FILE_NAME = "infosec_log";
   private static final long LOG_MAX_SIZE = 104857600L;
   private static final long LOG_MAX_TIME = 604800000L;
   public static Printer globalFilePrinter;
   public static boolean enablePhoneCopy;

   public static void initialization(Context context, String host, String base64HttpsTrustCert, String appID, String appSecret, Result.ResultListener resultListener) {
      Result context1;
      if (context == null) {
         context1 = new Result.<init>("IE1013");
         resultListener.handleResult(context1);
      } else if (TextUtils.isEmpty(host)) {
         context1 = new Result.<init>("IE1013");
         resultListener.handleResult(context1);
      } else {
         mContext = context;
         initXlog();
         IMSDefaultNetworkImpl var6;
         var6 = new IMSDefaultNetworkImpl.<init>(context, host, base64HttpsTrustCert);
         initialization(context, (NetworkInterface)var6, appID, appSecret, (Result.ResultListener)resultListener);
      }
   }

   public static Result initialization(Context context, String host, String base64HttpsTrustCert, String appID, String appSecret) {
      if (context == null) {
         return new Result("IE1013");
      } else if (TextUtils.isEmpty(host)) {
         return new Result("IE1013");
      } else {
         mContext = context;
         initXlog();
         return initialization(context, new IMSDefaultNetworkImpl(context, host, base64HttpsTrustCert), appID, appSecret);
      }
   }

   public static void initializationWithAppIndex(Context context, String host, String base64HttpsTrustCert, String appID, String appSecret, @NonNull Result.ResultListener resultListener) {
      Result context1;
      if (context == null) {
         context1 = new Result.<init>("IE1013");
         resultListener.handleResult(context1);
      } else if (TextUtils.isEmpty(host)) {
         context1 = new Result.<init>("IE1013");
         resultListener.handleResult(context1);
      } else {
         mContext = context;
         initXlog();
         isAppIndex = true;
         IMSDefaultNetworkImpl var6;
         var6 = new IMSDefaultNetworkImpl.<init>(context, host, base64HttpsTrustCert);
         initialization(context, (NetworkInterface)var6, appID, appSecret, (Result.ResultListener)resultListener);
      }
   }

   public static void initializationWithAppIndex(Context context, @NonNull NetworkInterface networkInterface, String appID, String appSecret, @NonNull Result.ResultListener resultListener) {
      if (context == null) {
         Result context1;
         context1 = new Result.<init>("IE1013");
         resultListener.handleResult(context1);
      } else {
         mContext = context;
         isAppIndex = true;
         initXlog();
         initialization(context, networkInterface, appID, appSecret, resultListener);
      }
   }

   public static void initialization(Context context, NetworkInterface networkInterface, String appID, String appSecret, @NonNull Result.ResultListener resultListener) {
      if (context == null) {
         Result context2;
         context2 = new Result.<init>("IE1013");
         resultListener.handleResult(context2);
      } else {
         Context var10001 = context;
         NetworkInterface var10002 = networkInterface;
         mContext = context;
         appIDentifier = appID;
         appSecretKey = appSecret;
         IMSAction networkInterface1;
         IMSAction var10003 = networkInterface1 = new IMSAction;
         networkInterface1.<init>(context);
         var10003.initNative(Util.getIdentifier(context));
         var10003.initLogger();
         IMSSdk.networkInterface = var10002;
         MAuthHandler context1;
         MAuthHandler var8 = context1 = new MAuthHandler;
         var8.<init>();
         var8.setFormatter(new JSONFormatter());
         mLogger.addHandler(context1);
         uploadRemainingLogs();
         resultListener.handleResult(initializationOnLine(var10001, networkInterface1));
      }
   }

   public static Result initialization(Context context, NetworkInterface networkInterface, String appID, String appSecret) {
      if (context == null) {
         return new Result("IE1013");
      } else {
         Context var10000 = context;
         NetworkInterface var10001 = networkInterface;
         mContext = context;
         appIDentifier = appID;
         appSecretKey = appSecret;
         IMSAction networkInterface1;
         IMSAction var10002 = networkInterface1 = new IMSAction;
         networkInterface1.<init>(context);
         var10002.initNative(Util.getIdentifier(context));
         var10002.initLogger();
         IMSSdk.networkInterface = var10001;
         MAuthHandler context1;
         MAuthHandler var6 = context1 = new MAuthHandler;
         var6.<init>();
         var6.setFormatter(new JSONFormatter());
         mLogger.addHandler(context1);
         uploadRemainingLogs();
         return initializationOnLine(var10000, networkInterface1);
      }
   }

   private static void initXlog() {
      LogConfiguration var0 = (new LogConfiguration.Builder()).tag("infosec").addInterceptor(new BlacklistTagsFilterInterceptor(new String[]{"blacklist1", "blacklist2", "blacklist3"})).build();
      AndroidPrinter var1;
      var1 = new AndroidPrinter.<init>(true);
      FilePrinter var2;
      FilePrinter var10000 = var2 = (new FilePrinter.Builder(getLogPath())).fileNameGenerator(new DateFileNameGenerator()).backupStrategy(new FileSizeBackupStrategy(104857600L)).cleanStrategy(new FileLastModifiedCleanStrategy(604800000L)).flattener(new ClassicFlattener()).writer(new SimpleWriter() {
         public void onNewFileCreated(File file) {
            super.onNewFileCreated(file);
            this.appendLog("\n>>>>>>>>>>>>>>>> File Header >>>>>>>>>>>>>>>>\nDevice Manufacturer: " + Build.MANUFACTURER + "\nDevice Model       : " + Build.MODEL + "\nAndroid Version    : " + VERSION.RELEASE + "\nAndroid SDK        : " + VERSION.SDK_INT + "\nSDK VersionName    : " + IMSSdk.version() + "\n<<<<<<<<<<<<<<<< File Header <<<<<<<<<<<<<<<<\n\n");
         }
      }).build();
      XLog.init(var0, new Printer[]{var1, var2});
      globalFilePrinter = var10000;
   }

   @Keep
   private static File getLogFile() {
      return mContext.getExternalCacheDir();
   }

   @Keep
   public static String getLogPath() {
      return (new File(getLogFile().getPath(), "infosec_log")).getPath();
   }

   @Keep
   public static boolean deleteLog() {
      File var0;
      File var10000 = var0 = new File;
      var10000.<init>(getLogFile().getPath(), "infosec_log");
      return var10000.exists() ? Util.deleteFolder(var0) : false;
   }

   private static void uploadRemainingLogs() {
      (new Thread() {
         public void run() {
            super.run();

            FileNotFoundException var30;
            label145: {
               IOException var10000;
               label133: {
                  boolean var10001;
                  ArrayList var31;
                  try {
                     var31 = new ArrayList;
                  } catch (FileNotFoundException var26) {
                     var30 = var26;
                     var10001 = false;
                     break label145;
                  } catch (IOException var27) {
                     var10000 = var27;
                     var10001 = false;
                     break label133;
                  }

                  ArrayList var28 = var31;

                  File var32;
                  try {
                     var31.<init>();
                     var32 = new File;
                  } catch (FileNotFoundException var24) {
                     var30 = var24;
                     var10001 = false;
                     break label145;
                  } catch (IOException var25) {
                     var10000 = var25;
                     var10001 = false;
                     break label133;
                  }

                  File var1;
                  File var33 = var1 = var32;

                  boolean var34;
                  try {
                     var33.<init>(IMSSdk.mContext.getCacheDir(), "IMSSDK_LOG_REMAINING.txt");
                     var34 = var32.exists();
                  } catch (FileNotFoundException var22) {
                     var30 = var22;
                     var10001 = false;
                     break label145;
                  } catch (IOException var23) {
                     var10000 = var23;
                     var10001 = false;
                     break label133;
                  }

                  if (!var34) {
                     return;
                  }

                  BufferedReader var35;
                  try {
                     var35 = new BufferedReader;
                  } catch (FileNotFoundException var20) {
                     var30 = var20;
                     var10001 = false;
                     break label145;
                  } catch (IOException var21) {
                     var10000 = var21;
                     var10001 = false;
                     break label133;
                  }

                  BufferedReader var2 = var35;

                  try {
                     var35.<init>(new FileReader(var1));
                  } catch (FileNotFoundException var18) {
                     var30 = var18;
                     var10001 = false;
                     break label145;
                  } catch (IOException var19) {
                     var10000 = var19;
                     var10001 = false;
                     break label133;
                  }

                  label108:
                  while(true) {
                     String var36;
                     try {
                        var36 = var2.readLine();
                     } catch (FileNotFoundException var14) {
                        var30 = var14;
                        var10001 = false;
                        break label145;
                     } catch (IOException var15) {
                        var10000 = var15;
                        var10001 = false;
                        break;
                     }

                     String var3 = var36;

                     try {
                        var34 = TextUtils.isEmpty(var36);
                     } catch (FileNotFoundException var12) {
                        var30 = var12;
                        var10001 = false;
                        break label145;
                     } catch (IOException var13) {
                        var10000 = var13;
                        var10001 = false;
                        break;
                     }

                     if (var34) {
                        try {
                           var31 = var28;
                           var2.close();
                           var1.delete();
                        } catch (FileNotFoundException var10) {
                           var30 = var10;
                           var10001 = false;
                           break label145;
                        } catch (IOException var11) {
                           var10000 = var11;
                           var10001 = false;
                           break;
                        }

                        Iterator var37;
                        try {
                           var37 = var31.iterator();
                        } catch (FileNotFoundException var8) {
                           var30 = var8;
                           var10001 = false;
                           break label145;
                        } catch (IOException var9) {
                           var10000 = var9;
                           var10001 = false;
                           break;
                        }

                        Iterator var29 = var37;

                        while(true) {
                           try {
                              var34 = var29.hasNext();
                           } catch (FileNotFoundException var6) {
                              var30 = var6;
                              var10001 = false;
                              break label145;
                           } catch (IOException var7) {
                              var10000 = var7;
                              var10001 = false;
                              break label108;
                           }

                           if (!var34) {
                              return;
                           }

                           try {
                              IMSSdk.transferLogRecord((String)var29.next());
                           } catch (FileNotFoundException var4) {
                              var30 = var4;
                              var10001 = false;
                              break label145;
                           } catch (IOException var5) {
                              var10000 = var5;
                              var10001 = false;
                              break label108;
                           }
                        }
                     }

                     try {
                        var28.add(var3);
                     } catch (FileNotFoundException var16) {
                        var30 = var16;
                        var10001 = false;
                        break label145;
                     } catch (IOException var17) {
                        var10000 = var17;
                        var10001 = false;
                        break;
                     }
                  }
               }

               var10000.printStackTrace();
               return;
            }

            var30.printStackTrace();
         }
      }).start();
   }

   public static void transferLogRecord(String logLine) {
      HashMap var1;
      HashMap var10000 = var1 = new HashMap;
      var10000.<init>();
      var10000.put("data", logLine);
      NetworkInterface var2 = networkInterface;
      String var10001 = "/".concat(APP_NAME).concat("/log/uploadLog");
      HashMap var10002 = var1;
      NetworkInterface.NetworkCallback var3;
      var3 = new NetworkInterface.NetworkCallback<JSONObject>() {
         public void onSucceed(@NonNull JSONObject callbackData) {
            super.decodeFilter(callbackData);
         }

         public void onFailed(@NonNull String errorMsg) {
            IOException var10000;
            label47: {
               File var8;
               boolean var10001;
               try {
                  var8 = new File;
               } catch (IOException var6) {
                  var10000 = var6;
                  var10001 = false;
                  break label47;
               }

               File errorMsg1;
               File var10 = errorMsg1 = var8;

               boolean var9;
               try {
                  var10.<init>(IMSSdk.mContext.getCacheDir(), "IMSSDK_LOG_REMAINING.txt");
                  var9 = var8.exists();
               } catch (IOException var5) {
                  var10000 = var5;
                  var10001 = false;
                  break label47;
               }

               if (!var9) {
                  try {
                     errorMsg1.createNewFile();
                  } catch (IOException var4) {
                     var10000 = var4;
                     var10001 = false;
                     break label47;
                  }
               }

               FileWriter var11;
               try {
                  var11 = new FileWriter;
               } catch (IOException var3) {
                  var10000 = var3;
                  var10001 = false;
                  break label47;
               }

               FileWriter var12 = var11;
               FileWriter var10002 = var11;
               FileWriter var10003 = var11;
               FileWriter var10004 = var11;

               try {
                  var10004.<init>(errorMsg1, true);
                  var10003.write(IMSSdk.this);
                  var10002.write("\r\n");
                  var12.flush();
                  var11.close();
                  return;
               } catch (IOException var2) {
                  var10000 = var2;
                  var10001 = false;
               }
            }

            var10000.printStackTrace();
         }
      }.<init>();
      var2.httpPost(var10001, var10002, var3);
   }

   private static synchronized Result initializationOnLine(@NonNull Context context, IMSAction imsAction) {
      Exception var10000;
      label185: {
         boolean var10001;
         Map var38;
         try {
            var38 = imsAction.initOnLineBegin();
         } catch (Exception var29) {
            var10000 = var29;
            var10001 = false;
            break label185;
         }

         Map var2 = var38;

         NetworkInterface var39;
         try {
            var39 = networkInterface;
         } catch (Exception var28) {
            var10000 = var28;
            var10001 = false;
            break label185;
         }

         NetworkInterface var3 = var39;
         String var40 = "/";

         try {
            var40 = var40.concat(APP_NAME);
         } catch (Exception var27) {
            var10000 = var27;
            var10001 = false;
            break label185;
         }

         String var4 = var40;

         boolean var41;
         try {
            var41 = isAppIndex;
         } catch (Exception var26) {
            var10000 = var26;
            var10001 = false;
            break label185;
         }

         String var5;
         if (var41) {
            var5 = "/mobile/registerNew";
         } else {
            var5 = "/mobile/register";
         }

         JSONObject var42;
         try {
            var42 = var3.httpPost(var4.concat(var5), var2);
         } catch (Exception var25) {
            var10000 = var25;
            var10001 = false;
            break label185;
         }

         JSONObject var34 = var42;
         if (var42 == null) {
            try {
               imsAction.clearAPICheckType();
               XLog.d("SDK初始化失败");
               return new Result("IE1015", "初始化失败，responseData == null");
            } catch (Exception var6) {
               var10000 = var6;
               var10001 = false;
            }
         } else {
            label193: {
               Result var43;
               try {
                  var43 = imsAction.initOnLineFinal(var34);
               } catch (Exception var24) {
                  var10000 = var24;
                  var10001 = false;
                  break label193;
               }

               Result var37 = var43;
               var40 = "000000";

               try {
                  var41 = TextUtils.equals(var40, var37.getResultID());
               } catch (Exception var23) {
                  var10000 = var23;
                  var10001 = false;
                  break label193;
               }

               if (!var41) {
                  NetworkStateReceiver var45;
                  try {
                     imsAction.clearAPICheckType();
                     var45 = networkStateReceiver;
                  } catch (Exception var22) {
                     var10000 = var22;
                     var10001 = false;
                     break label193;
                  }

                  if (var45 == null) {
                     try {
                        networkStateReceiver = new NetworkStateReceiver();
                     } catch (Exception var21) {
                        var10000 = var21;
                        var10001 = false;
                        break label193;
                     }
                  }

                  try {
                     var41 = monitoringNetworkState;
                  } catch (Exception var20) {
                     var10000 = var20;
                     var10001 = false;
                     break label193;
                  }

                  if (!var41) {
                     IntentFilter var44;
                     Context var47;
                     try {
                        var47 = context;
                        var44 = new IntentFilter;
                     } catch (Exception var19) {
                        var10000 = var19;
                        var10001 = false;
                        break label193;
                     }

                     IntentFilter context1;
                     IntentFilter var10002 = context1 = var44;

                     Intent var48;
                     try {
                        var10002.<init>();
                        var44.addAction("android.net.conn.CONNECTIVITY_CHANGE");
                        var48 = var47.registerReceiver(networkStateReceiver, context1);
                     } catch (Exception var18) {
                        var10000 = var18;
                        var10001 = false;
                        break label193;
                     }

                     boolean context2;
                     if (var48 != null) {
                        context2 = true;
                     } else {
                        context2 = false;
                     }

                     try {
                        monitoringNetworkState = context2;
                     } catch (Exception var17) {
                        var10000 = var17;
                        var10001 = false;
                        break label193;
                     }
                  }
               }

               int var49;
               try {
                  var49 = imsAction.getAPICheckType();
               } catch (Exception var16) {
                  var10000 = var16;
                  var10001 = false;
                  break label193;
               }

               int context3 = var49;
               JSONObject context5;
               if (var49 != 2 && context3 != 3) {
                  context5 = var34;
               } else {
                  try {
                     var41 = isAppIndex;
                  } catch (Exception var15) {
                     var10000 = var15;
                     var10001 = false;
                     break label193;
                  }

                  Map context4;
                  String var46;
                  if (var41) {
                     try {
                        var38 = imsAction.testAppIdBegin();
                     } catch (Exception var14) {
                        var10000 = var14;
                        var10001 = false;
                        break label193;
                     }

                     context4 = var38;

                     try {
                        var39 = networkInterface;
                     } catch (Exception var13) {
                        var10000 = var13;
                        var10001 = false;
                        break label193;
                     }

                     var46 = "/";

                     try {
                        var42 = var39.httpPost(var46.concat(APP_NAME).concat("/config/testAppId"), context4);
                     } catch (Exception var12) {
                        var10000 = var12;
                        var10001 = false;
                        break label193;
                     }
                  } else {
                     try {
                        var38 = imsAction.verifyAppIdBegin();
                     } catch (Exception var11) {
                        var10000 = var11;
                        var10001 = false;
                        break label193;
                     }

                     context4 = var38;

                     try {
                        var39 = networkInterface;
                     } catch (Exception var10) {
                        var10000 = var10;
                        var10001 = false;
                        break label193;
                     }

                     var46 = "/";

                     try {
                        var42 = var39.httpPost(var46.concat(APP_NAME).concat("/config/verifyAppId"), context4);
                     } catch (Exception var9) {
                        var10000 = var9;
                        var10001 = false;
                        break label193;
                     }
                  }

                  context5 = var42;

                  try {
                     var43 = imsAction.commonFinal(context5);
                  } catch (Exception var8) {
                     var10000 = var8;
                     var10001 = false;
                     break label193;
                  }

                  var37 = var43;
               }

               try {
                  XLog.d("SDK初始化结果：" + context5);
                  return var37;
               } catch (Exception var7) {
                  var10000 = var7;
                  var10001 = false;
               }
            }
         }
      }

      Exception context6 = var10000;
      XLog.d("SDK初始化失败：" + context6);
      return new Result("IE1015", context6);
   }

   public static String deviceIdentifier() {
      return Util.getIdentifier(mContext);
   }

   public static String version() {
      return "移动安全中间件主线3.0.13.2_Android_build20241217".concat(":").concat(getVersionNative());
   }

   public static void enableLogRequestTime(boolean logRequestTime) {
      enableLogRequestTime = logRequestTime;
   }

   public static void enableDebugLog(boolean enableDebugLog) {
      IMSSdk.enableDebugLog = enableDebugLog;
   }

   public static void enablePhoneCopy(boolean enablePhoneCopy) {
      IMSSdk.enablePhoneCopy = enablePhoneCopy;
   }

   public static boolean isCollaborative() {
      return (new IMSAction(mContext)).isCollaborative();
   }

   public static int genP10Model() {
      return (new IMSAction(mContext)).genP10Model();
   }

   public static boolean isCertAvailable() {
      return (new IMSAction(mContext)).isCertAvailable();
   }

   public static boolean isTokenAvailable() {
      return (new IMSAction(mContext)).isTokenAvailable();
   }

   public static boolean isPDFAvailable() {
      return (new IMSAction(mContext)).isPDFAvailable();
   }

   public static boolean isSignAvailable() {
      return (new IMSAction(mContext)).isSignAvailable();
   }

   public static boolean isAppForceUpdate() {
      return (new IMSAction(mContext)).isAppForceUpdate();
   }

   public static int getQRLoginPriority() {
      return (new IMSAction(mContext)).getQRLoginPriority();
   }

   public static boolean isInfosecCollaborative() {
      return (new IMSAction(mContext)).isInfosecCollaborative();
   }

   public static boolean isServerPDFMode() {
      return (new IMSAction(mContext)).isServerPDFMode();
   }

   public static boolean isPairedCert() {
      return (new IMSAction(mContext)).isPairedCert();
   }

   public static int getSealerImageSize() {
      return (new IMSAction(mContext)).getSealerImageSize();
   }

   public static int getQRCodeExpireMillSeconds() {
      return (new IMSAction(mContext)).getQRCodeExpireMillSeconds();
   }

   public static int getSignCodeExpireMillSeconds() {
      return (new IMSAction(mContext)).getSignCodeExpireMillSeconds();
   }

   public static boolean clientRegistEnable() {
      return (new IMSAction(mContext)).clientRegistEnable();
   }

   public static int getSignAndTokenMode() {
      return (new IMSAction(mContext)).getSignAndTokenMode();
   }

   public static int getOTPLength() {
      return (new IMSAction(mContext)).getOTPLength();
   }

   @Keep
   public static native boolean initializationNative(Context var0, String var1);

   @Keep
   public static native String getVersionNative();

   @Keep
   public static void setNetworkTimeout(int millSeconds) {
      timeoutMillSeconds = millSeconds;
   }

   @Keep
   public static native void enableOutputNative(boolean var0);

   static {
      System.loadLibrary("sm9");
      System.loadLibrary("InfosecMSSL");
      Security.insertProviderAt(new InfosecProvider(), 99);
   }

   private static final class NetworkStateReceiver extends BroadcastReceiver {
      private NetworkStateReceiver() {
      }

      // $FF: synthetic method
      NetworkStateReceiver(Object x0) {
         this();
      }

      public void onReceive(Context context, Intent intent) {
         if (TextUtils.equals("android.net.conn.CONNECTIVITY_CHANGE", intent.getAction())) {
            ConnectivityManager var3;
            if ((var3 = (ConnectivityManager)context.getSystemService("connectivity")) != null) {
               if (VERSION.SDK_INT >= 23) {
                  if (var3.getActiveNetwork() == null) {
                     return;
                  }
               } else if (var3.getActiveNetworkInfo() == null) {
                  return;
               }

               XLog.d("网络恢复，重新初始化");
               Context var4;
               Context var10000 = var4 = IMSSdk.mContext;
               IMSAction context1;
               context1 = new IMSAction.<init>(var4);
               IMSSdk.initializationOnLine(var10000, context1);
            }
         }
      }
   }
}
